@@ -22,7 +22,7 @@
 #' @references
 #' Van den Burg, G.J.J. and Groenen, P.J.F. (2016). \emph{GenSVM: A Generalized 
 #' Multiclass Support Vector Machine}, Journal of Machine Learning Research, 
-#' 17(225):1--42. URL \url{http://jmlr.org/papers/v17/14-526.html}.
+#' 17(225):1--42. URL \url{https://jmlr.org/papers/v17/14-526.html}.
 #'
 #' @seealso
 #' \code{\link{gensvm}}, \code{\link{predict.gensvm.grid}}, 
@@ -49,8 +49,7 @@
 predict.gensvm.grid <- function(object, newdata, ...)
 {
     if (is.null(object$best.estimator)) {
-        cat("Error: Can't predict, the best.estimator element is NULL\n")
-        return
+        stop("Error: Can't predict, the best.estimator element is NULL\n")
     }
 
     return(predict(object$best.estimator, newdata, ...))
